@@ -37,7 +37,7 @@ def validate_db():
 def validate_collect():
     logger.info("Validating Collect variables")
     v = [
-        Validator("ALIAS", len_eq=2, must_exist=True),
+        Validator("ALIAS", must_exist=True),
         Validator("GRAU", len_eq=2, must_exist=True),
         Validator("OBJS_SQL", "KEYS_SQL", must_exist=True),
     ]
