@@ -58,10 +58,17 @@ def init(name):
     default=None,
     help="Path for .secrets file, if not passed default is .secrets.toml",
 )
-def query(sql, name, settings, secrets):
+@click.option(
+    "--save",
+    type=click.Choice(["S3", "local"], case_sensitive=False),
+    default="local",
+    help="Choose where to save files. If not passed default is local",
+)
+def query(sql, name, settings, secrets, save):
     load_sett_files(settings, secrets)
+
     validate_db()
-    q = Query()
+    q = Query(save)
     q.run(sql, name)
     logger.info("Successful query command")
 
